@@ -14,6 +14,6 @@ else:
     _homedir = os.environ['HOME']
 
 # define variables
-__all__ = ['bdata', 'bjoined', 'bmerged', 'life']
+__all__ = ['bdata', 'bjoined', 'bmerged', 'life', 'calc']
 __author__ = 'Derek Fujimoto'
 _mud_data = os.path.join(_homedir, '.bdata')
