@@ -7,7 +7,7 @@ from bdata import bdata
 from mudpy.containers import mdict, mhist, mlist, mvar
 import numpy as np
 import pandas as pd
-import re
+import re, warnings, copy
 
 class bmerged(bdata):
     """
@@ -51,7 +51,9 @@ class bmerged(bdata):
             
             d = mdict()
             
-            keys = list(getattr(bdata_list[0], top).keys())
+            keys = [list(getattr(b, top).keys()) for b in bdata_list]
+            keys = np.unique(np.concatenate(keys)).tolist()
+
             x = mlist([getattr(b, top) for b in bdata_list])
             for key in keys:
                 d[key] = self._combine_var(x[key])
@@ -81,7 +83,8 @@ class bmerged(bdata):
             SLR histograms are summed.
         """
         
-        hist = mlist([b.hist for b in bdata_list])
+        # make copy
+        bdata_list = mlist(copy.deepcopy(bdata_list))
         
         # these will get combined
         hist_names = ('F+', 'F-', 'B+', 'B-', 
@@ -95,6 +98,7 @@ class bmerged(bdata):
         hist_joined = mdict()
         
         # check if x values in histogram
+        hist = bdata_list.hist
         do_append = any([h in hist[0] for h in hist_xnames])
         
         # get x histogram name
@@ -103,7 +107,9 @@ class bmerged(bdata):
                 if xname in hist[0]: 
                     break
             
-        for name in hist[0].keys():
+        hist_keys = np.unique(np.concatenate([list(h.keys()) for h in hist])).tolist()
+            
+        for name in hist_keys:
             
             # no rule for combining histogram
             if (name not in hist_names) and (name not in hist_xnames): continue
@@ -113,17 +119,57 @@ class bmerged(bdata):
                         
             # combine scan-less runs (just add the histogrms)
             if not do_append:
-                hist_obj.data = np.sum(list(hist[name].data), axis=0)
             
+                # get list of histograms
+                hist_list = hist[name]
+            
+                # check that histograms are all same length
+                len0 = len(hist_list[0])
+                if not all((len0 == len(h) for h in hist_list)):
+                    
+                    # check ppg parameters for source of mismatch
+                    dwell = bdata_list.dwelltime.mean
+                    prebeam = bdata_list.prebeam.mean
+                    beam_on = bdata_list.beam_on.mean
+                    beam_off = bdata_list.beam_off.mean
+                    
+                    # if not equal, nothing we can do
+                    if not all((dwell[0] == d for d in dwell)):
+                        raise RuntimeError("dwelltime mismatch, unable to combine histograms")
+                    
+                    # if not equal, nothing we can do                    
+                    if not all((beam_on[0] == d for d in beam_on)):
+                        raise RuntimeError("beam_on mismatch, unable to combine histograms")
+
+                    # if not equal, trim histogram to match
+                    if not all((prebeam[0] == d for d in prebeam)):
+                        warnings.warn("prebeam mismatch, truncating historam head by mismatch amount")
+                        smallest = min(prebeam)
+                        for i, (p, h) in enumerate(zip(prebeam, hist_list)):
+                            if p > smallest:
+                                diff = int(p - smallest)
+                                hist_list[i].data = h.data[diff:]
+                    
+                    # if not equal, trim histogram to match            
+                    if not all((beam_off[0] == d for d in beam_off)):
+                        warnings.warn("beam_off mimatch, truncating historam tail by mismatch amount")
+                        smallest = min(beam_off)
+                        for i, (p, h) in enumerate(zip(beam_off, hist_list)):
+                            if p > smallest:
+                                diff = int(p - smallest)
+                                hist_list[i].data = h.data[:-diff]
+               
+                hist_obj.data = np.sum(list(hist_list.data), axis=0)
+         
             # combine runs with scans (append the data)
             else:
-                hist_obj.data = np.concatenate(hist[name].data)    
+                hist_obj.data = np.concatenate(list(hist[name].data))    
             
             # set common histogram attributes
             hist_obj.title = name
-            
+
             for key in ('background1', 'background2', 'n_events', 'n_bytes'):
-                setattr(hist_obj, key, int(np.sum(getattr(hist[name], key))))
+                setattr(hist_obj, key, int(np.sum(getattr(hist[name], key, 0))))
                 
             for key in ('id_number', 'n_bins', 'good_bin1', 'good_bin2', 't0_bin', 
                         't0_ps', 's_per_bin', 'fs_per_bin', 'htype'):
